@@ -25,6 +25,18 @@ extern std::string		WrapDir;
 extern std::string		TalkDir;
 extern std::string		TempDir;
 extern std::string		PskMailDir;
+extern std::string		NBEMS_dir;
+extern std::string		ARQ_dir;
+extern std::string		ARQ_files_dir;
+extern std::string		ARQ_recv_dir;
+extern std::string		ARQ_send;
+extern std::string		WRAP_dir;
+extern std::string		WRAP_recv_dir;
+extern std::string		WRAP_send_dir;
+extern std::string		WRAP_auto_dir;
+extern std::string		ICS_dir;
+extern std::string		ICS_msg_dir;
+extern std::string		ICS_tmp_dir;
 
 extern std::string		xmlfname;
 
@@ -49,7 +61,7 @@ extern char			arq_get_char();
 // ARQ mail implementation
 extern void			arq_init();
 extern void			arq_close();
-extern void			WriteARQ(unsigned int);
+extern void			WriteARQ(unsigned char);
 extern void			checkTLF();
 
 #define ARQBUFSIZ 8192
@@ -69,4 +81,7 @@ extern int rxmsgid;
 extern TXMSGSTRUC txmsgst;
 extern int txmsgid;
 
+void check_nbems_dirs(void);
+extern bool nbems_dirs_checked;
+
 #endif
