@@ -1,7 +1,7 @@
 // ----------------------------------------------------------------------------
 // interleave.cxx  --  MFSK (de)interleaver
 //
-// Copyright (C) 2006
+// Copyright (C) 2006-2008
 //		Dave Freese, W1HKJ
 //
 // This file is part of fldigi.  Adapted from code contained in gmfsk source code 
@@ -9,19 +9,18 @@
 //  gmfsk Copyright (C) 2001, 2002, 2003
 //  Tomi Manninen (oh2bns@sral.fi)
 //
-// fldigi is free software; you can redistribute it and/or modify
+// Fldigi is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
+// the Free Software Foundation, either version 3 of the License, or
 // (at your option) any later version.
 //
-// fldigi is distributed in the hope that it will be useful,
+// Fldigi is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with fldigi; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// along with fldigi.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #include <config.h>
@@ -38,6 +37,19 @@ interleave::interleave (int _size, int dir)
 	if (size == -1) { // dominoEX interleaver
 		size = 4;
 		depth = 4;
+//BPSK+FEC+interleaver. First digit is size, then number of concatenated square interleavers
+	} else if (size == -220) { // BPSK FEC + Interleaver 2x2x20
+		size = 2;
+		depth = 20;
+	} else if (size == -240) { // BPSK FEC + Interleaver 2x2x40
+		size = 2;
+		depth = 40;
+	} else if (size == -280) { // BPSK FEC + Interleaver 2x2x80
+		size = 2;
+		depth = 80;
+	} else if (size == -2160) { // BPSK FEC + Interleaver 2x2x160
+		size = 2;
+		depth = 160;
 	} else if (size == 5)
 		depth = 5;
 	else
