@@ -42,6 +42,7 @@
 
 using namespace std;
 
+modem *null_modem = 0;
 modem *cw_modem = 0;
 
 modem *mfsk8_modem = 0;
@@ -223,6 +224,12 @@ void modem::set_metric(double m)
 	metric = m;
 }
 
+void modem::display_metric(double m)
+{
+	set_metric(m);
+	::global_display_metric(m);
+}
+
 double modem::get_metric(void)
 {
 	return metric;
